==> duiba-activity-service-api-0.0.1-20220328.074947-24-sources.jar: cn/com/duiba/cloud/duiba/activity/service/api/remoteservice/playways/AbstractPlayWay.java <==
package cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways;

import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote.RemoteKeyValueApi;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote.RemoteLockService;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote.RemoteQueryTableService;
import cn.com.duiba.cloud.duiba.activity.service.api.enums.PlaywayEnum;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote.RemoteRankingApi;
import cn.com.duiba.cloud.duiba.activity.service.api.utils.Field;

import javax.annotation.Resource;

public abstract class AbstractPlayWay {

    @Resource
    private RemoteQueryTableService queryTableService;
    @Resource(name = "keyValueApiRedisImpl")
    protected RemoteKeyValueApi keyValueApi;
    @Resource
    private RemoteLockService lockService;
    /**
     * 排行榜api
     */
    @Resource
    protected RemoteRankingApi rankingApi;
//    /**
//     * 事务执行API
//     */
//    @Resource
//    protected ProjectTransactionApi transactionApi;

    /**
     * 创建一个分布式锁
     *
     * @param key
     * @param expireSeconds
     * @return
     */
    protected DistributedLock newLock(Long activityId, String key, int expireSeconds) {
        return lockService.newLock(redisKey(activityId, key), expireSeconds);
    }

    protected <T extends Field> QueryTable<T> getTable(Long activityId, String group, Class<T> clazz) {
        return new QueryTableImpl<>(group, clazz, activityId, queryTableService);
    }

    protected abstract PlaywayEnum getPlayWay();

    /**
     * 生成项目环境的rediSkey
     * @param key
     * @return
     */
    private String redisKey(Long activityId, String key) {
        return activityId + "-" + key;
    }
}

==> duiba-activity-service-api-0.0.1-20220401.100053-74-sources.jar: cn/com/duiba/cloud/duiba/activity/service/api/remoteservice/playways/AbstractPlayWay.java <==
package cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways;

import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.enums.PlaywayEnum;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote.RemoteKeyValueApi;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote.RemoteLockService;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote.RemoteQueryTableService;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote.RemoteRankingApi;
import cn.com.duiba.cloud.duiba.activity.service.api.utils.Field;

import javax.annotation.Resource;

public abstract class AbstractPlayWay {

    @Resource
    private RemoteQueryTableService queryTableService;
    @Resource(name = "keyValueApiRedisImpl")
    protected RemoteKeyValueApi keyValueApi;
    @Resource
    private RemoteLockService lockService;
    /**
     * 排行榜api
     */
    @Resource
    protected RemoteRankingApi rankingApi;
//    /**
//     * 事务执行API
//     */
//    @Resource
//    protected ProjectTransactionApi transactionApi;

    /**
     * 创建一个分布式锁
     *
     * @param key
     * @param expireSeconds
     * @return
     */
    protected DistributedLock newLock(Long activityId, String key, int expireSeconds) {
        return lockService.newLock(redisKey(activityId, key), expireSeconds);
    }

    protected <T extends Field> QueryTable<T> getTable(Long activityId, String group, Class<T> clazz) {
        return new QueryTableImpl<>(group, clazz, activityId, queryTableService);
    }

    protected abstract PlaywayEnum getPlayWay();

    /**
     * 生成项目环境的rediSkey
     * @param key
     * @return
     */
    private String redisKey(Long activityId, String key) {
        return activityId + "-" + key;
    }
}
